pyjabber.features.feature\_utils package
========================================

Submodules
----------

pyjabber.features.feature\_utils.RosterUtils module
---------------------------------------------------

.. automodule:: pyjabber.features.feature_utils.RosterUtils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pyjabber.features.feature_utils
   :members:
   :undoc-members:
   :show-inheritance:
